{% extends "base.html" %}
{% block content %}
<div class="content-header">
    <h3>Historial de Nóminas: {{ planilla.nombre }}</h3>
    <div>
        <a href="{{ url_for('planilla.edit', planilla_id=planilla.id) }}" class="btn btn-secondary">
            <i class="fas fa-arrow-left"></i> Volver a Planilla
        </a>
        <a href="{{ url_for('planilla.ejecutar_nomina', planilla_id=planilla.id) }}" class="btn btn-primary">
            <i class="fas fa-play"></i> Nueva Ejecución
        </a>
    </div>
</div>

<div class="card">
    <div class="card-body">
        {% if nominas %}
        <table class="table table-striped table-hover">
            <thead>
                <tr>
                    <th>Período</th>
                    <th>Fecha Generación</th>
                    <th>Estado</th>
                    <th class="text-right">Total Bruto</th>
                    <th class="text-right">Total Deducciones</th>
                    <th class="text-right">Total Neto</th>
                    <th>Generado Por</th>
                    <th>Acciones</th>
                </tr>
            </thead>
            <tbody>
                {% for nomina in nominas %}
                <tr>
                    <td>
                        {{ nomina.periodo_inicio.strftime('%d/%m/%Y') }} -
                        {{ nomina.periodo_fin.strftime('%d/%m/%Y') }}
                    </td>
                    <td>{{ nomina.fecha_generacion.strftime('%d/%m/%Y %H:%M') }}</td>
                    <td>
                        {% if nomina.estado == 'calculando' %}
                        <span class="badge bg-primary">
                            <i class="fas fa-spinner fa-spin"></i> Calculando
                            {% if nomina.total_empleados and nomina.total_empleados > 0 %}
                            ({{ nomina.empleados_procesados }}/{{ nomina.total_empleados }})
                            {% endif %}
                        </span>
                        {% elif nomina.estado == 'generado' %}
                        <span class="badge bg-warning">Generado</span>
                        {% elif nomina.estado == 'aprobado' %}
                        <span class="badge bg-info">Aprobado</span>
                        {% elif nomina.estado == 'aplicado' %}
                        <span class="badge bg-success">Aplicado</span>
                        {% elif nomina.estado == 'error' %}
                        <span class="badge bg-danger">Error</span>
                        {% else %}
                        <span class="badge bg-secondary">{{ nomina.estado }}</span>
                        {% endif %}
                    </td>
                    <td class="text-right">{{ "{:,.2f}".format(nomina.total_bruto|float) }}</td>
                    <td class="text-right">{{ "{:,.2f}".format(nomina.total_deducciones|float) }}</td>
                    <td class="text-right"><strong>{{ "{:,.2f}".format(nomina.total_neto|float) }}</strong></td>
                    <td>{{ nomina.generado_por or 'N/A' }}</td>
                    <td>
                        <a href="{{ url_for('planilla.ver_nomina', planilla_id=planilla.id, nomina_id=nomina.id) }}"
                           class="btn btn-sm btn-outline-primary" title="Ver Detalle">
                            <i class="bi bi-eye"></i>
                        </a>
                        {% if nomina.estado == 'error' %}
                        <form action="{{ url_for('planilla.reintentar_nomina', planilla_id=planilla.id, nomina_id=nomina.id) }}"
                              method="post" style="display: inline;" class="ms-1">
                            <button type="submit" class="btn btn-sm btn-warning" 
                                    onclick="return confirm('¿Reintentar esta nómina?')"
                                    title="Reintentar Procesamiento">
                                <i class="fas fa-redo"></i>
                            </button>
                        </form>
                        {% endif %}
                    </td>
                </tr>
                {% endfor %}
            </tbody>
        </table>
        {% else %}
        <div class="alert alert-info">
            <i class="fas fa-info-circle"></i> No hay nóminas generadas para esta planilla.
            <a href="{{ url_for('planilla.ejecutar_nomina', planilla_id=planilla.id) }}">Ejecutar primera nómina</a>
        </div>
        {% endif %}
    </div>
</div>
{% endblock %}
