# Copyright 2025 BMO Soluciones, S.A.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Repository layer for data access."""

from .base_repository import BaseRepository
from .planilla_repository import PlanillaRepository
from .employee_repository import EmployeeRepository
from .acumulado_repository import AcumuladoRepository
from .novelty_repository import NoveltyRepository
from .exchange_rate_repository import ExchangeRateRepository
from .config_repository import ConfigRepository

__all__ = [
    "BaseRepository",
    "PlanillaRepository",
    "EmployeeRepository",
    "AcumuladoRepository",
    "NoveltyRepository",
    "ExchangeRateRepository",
    "ConfigRepository",
]
