# Copyright 2025 BMO Soluciones, S.A.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Processors for specialized payroll operations."""

from .loan_processor import LoanProcessor
from .accumulation_processor import AccumulationProcessor
from .vacation_processor import VacationProcessor
from .novelty_processor import NoveltyProcessor
from .accounting_processor import AccountingProcessor

__all__ = [
    "LoanProcessor",
    "AccumulationProcessor",
    "VacationProcessor",
    "NoveltyProcessor",
    "AccountingProcessor",
]
