# Copyright 2025 BMO Soluciones, S.A.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Helper functions for planilla views."""

from coati_payroll.vistas.planilla.helpers.form_helpers import (
    populate_form_choices,
    populate_novedad_form_choices,
    get_concepto_ids_from_form,
)
from coati_payroll.vistas.planilla.helpers.excel_helpers import check_openpyxl_available
from coati_payroll.vistas.planilla.helpers.association_helpers import (
    agregar_asociacion,
    get_planilla_component_counts,
)

__all__ = [
    "populate_form_choices",
    "populate_novedad_form_choices",
    "get_concepto_ids_from_form",
    "check_openpyxl_available",
    "agregar_asociacion",
    "get_planilla_component_counts",
]
