{% extends "base.html" %}
{% block content %}
<div class="content-header">
    <h3>Ejecutar Nómina: {{ planilla.nombre }}</h3>
    <a href="{{ url_for('planilla.edit', planilla_id=planilla.id) }}" class="btn btn-secondary">
        <i class="fas fa-arrow-left"></i> Volver a Planilla
    </a>
</div>

<div class="card">
    <div class="card-header">
        <h5>Configuración de Ejecución</h5>
    </div>
    <div class="card-body">
        {% if ultima_nomina %}
        <div class="alert alert-info mb-4">
            <strong>Última nómina:</strong> 
            {{ ultima_nomina.periodo_inicio.strftime('%d/%m/%Y') }} - 
            {{ ultima_nomina.periodo_fin.strftime('%d/%m/%Y') }}
            (Estado: {{ ultima_nomina.estado }})
        </div>
        {% endif %}

        <form method="post" action="{{ url_for('planilla.ejecutar_nomina', planilla_id=planilla.id) }}">
            <div class="row">
                <div class="col-md-4">
                    <div class="form-group">
                        <label for="periodo_inicio">Período Inicio *</label>
                        <input type="date" class="form-control" id="periodo_inicio" name="periodo_inicio"
                               value="{{ periodo_inicio.isoformat() }}" required>
                    </div>
                </div>
                <div class="col-md-4">
                    <div class="form-group">
                        <label for="periodo_fin">Período Fin *</label>
                        <input type="date" class="form-control" id="periodo_fin" name="periodo_fin"
                               value="{{ periodo_fin.isoformat() }}" required>
                    </div>
                </div>
                <div class="col-md-4">
                    <div class="form-group">
                        <label for="fecha_calculo">Fecha de Cálculo</label>
                        <input type="date" class="form-control" id="fecha_calculo" name="fecha_calculo"
                               value="{{ fecha_calculo.isoformat() }}">
                        <small class="form-text text-muted">Si no se especifica, se usa la fecha actual.</small>
                    </div>
                </div>
            </div>

            <div class="card mt-4">
                <div class="card-header bg-light">
                    <h6 class="mb-0">Resumen de la Planilla</h6>
                </div>
                <div class="card-body">
                    <div class="row">
                        <div class="col-md-3">
                            <strong>Tipo de Planilla:</strong><br>
                            {{ planilla.tipo_planilla.descripcion if planilla.tipo_planilla else 'N/A' }}
                        </div>
                        <div class="col-md-3">
                            <strong>Moneda:</strong><br>
                            {{ planilla.moneda.codigo if planilla.moneda else 'N/A' }}
                        </div>
                        <div class="col-md-3">
                            <strong>Empleados:</strong><br>
                            {{ planilla.planilla_empleados|selectattr('activo')|list|length }}
                        </div>
                        <div class="col-md-3">
                            <strong>Periodicidad:</strong><br>
                            {{ planilla.tipo_planilla.periodicidad|capitalize if planilla.tipo_planilla else 'N/A' }}
                        </div>
                    </div>
                    <hr>
                    <div class="row">
                        <div class="col-md-3">
                            <strong>Percepciones:</strong><br>
                            {{ planilla.planilla_percepciones|length }}
                        </div>
                        <div class="col-md-3">
                            <strong>Deducciones:</strong><br>
                            {{ planilla.planilla_deducciones|length }}
                        </div>
                        <div class="col-md-3">
                            <strong>Prestaciones:</strong><br>
                            {{ planilla.planilla_prestaciones|length }}
                        </div>
                        <div class="col-md-3">
                            <strong>Reglas de Cálculo:</strong><br>
                            {{ planilla.planilla_reglas_calculo|length }}
                        </div>
                    </div>
                </div>
            </div>

            <div class="mt-4">
                <button type="submit" class="btn btn-primary btn-lg">
                    <i class="fas fa-play"></i> Ejecutar Nómina
                </button>
                <a href="{{ url_for('planilla.listar_nominas', planilla_id=planilla.id) }}" class="btn btn-outline-secondary">
                    <i class="fas fa-list"></i> Ver Historial de Nóminas
                </a>
            </div>
        </form>
    </div>
</div>
{% endblock %}
